==> order-center-domain-3.0.0-CLOUD-DEV-20250409.072946-169-sources.jar: com/tydic/dyc/oc/model/aforder/qrybo/UocAfOrderMapQryBo.java <==
package com.tydic.dyc.oc.model.aforder.qrybo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocAfOrderMapQryBo
 * 说明:售后服务单扩展
 * 时间:2022-02-23 20:57
 * 作者:罗有
 **/
@Data
public class UocAfOrderMapQryBo implements Serializable {
	private static final long serialVersionUID = 1225047834104918870L;

	@DocField(value = "id")
	private Long id;

	@DocField(value = "售后服务单id")
	private Long afOrderId;

	@DocField(value = "验收单id")
	private Long inspOrderId;


	@DocField(value = "销售单id")
	private Long saleOrderId;

	@DocField(value = "发货单id")
	private Long shipOrderId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "字段编码")
	private String fieldCode;

	@DocField(value = "字段名称")
	private String fieldName;

	@DocField(value = "字段值")
	private String fieldValue;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "排序")
	private String orderBy;

	/**
	 * 租户id
	 */
	private Long sysTenantId;
	private String sysTenantName;
}

==> order-center-domain-3.1.0-CLOUD-DEV-20230625.084845-58-sources.jar: com/tydic/dyc/oc/model/aforder/qrybo/UocAfOrderMapQryBo.java <==
package com.tydic.dyc.oc.model.aforder.qrybo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocAfOrderMapQryBo
 * 说明:售后服务单扩展
 * 时间:2022-02-23 20:57
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocAfOrderMapQryBo implements Serializable {
	private static final long serialVersionUID = 1225047834104918870L;

	@DocField(value = "id")
	private Long id;

	@DocField(value = "售后服务单id")
	private Long afOrderId;

	@DocField(value = "验收单id")
	private Long inspOrderId;


	@DocField(value = "销售单id")
	private Long saleOrderId;

	@DocField(value = "发货单id")
	private Long shipOrderId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "字段编码")
	private String fieldCode;

	@DocField(value = "字段名称")
	private String fieldName;

	@DocField(value = "字段值")
	private String fieldValue;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "排序")
	private String orderBy;
}
